@@ -2,7 +2,7 @@
 #
 # pgAdmin 4 - PostgreSQL Tools
 #
-# Copyright (C) 2013 - 2017, The pgAdmin Development Team
+# Copyright (C) 2013 - 2019, The pgAdmin Development Team
 # This software is released under the PostgreSQL Licence
 #
 ##########################################################################
@@ -12,23 +12,26 @@ import re
 from functools import wraps
 
 import pgadmin.browser.server_groups.servers.databases as database
-from flask import render_template, make_response, request, jsonify
-from flask_babel import gettext
+from flask import render_template, request, jsonify
+from flask_babelex import gettext
 from pgadmin.browser.collection import CollectionNodeModule
 from pgadmin.browser.utils import PGChildNodeView
 from pgadmin.utils.ajax import make_json_response, internal_server_error, \
-    make_response as ajax_response
+    make_response as ajax_response, gone
 from pgadmin.utils.driver import get_driver
-from pgadmin.utils.ajax import gone
-
 from config import PG_DEFAULT_DRIVER
+from pgadmin.utils import IS_PY2
+# If we are in Python3
+if not IS_PY2:
+    unicode = str
 
 
 class EventTriggerModule(CollectionNodeModule):
     """
     class EventTriggerModule(CollectionNodeModule)
 
-        A module class for Event trigger node derived from CollectionNodeModule.
+        A module class for Event trigger node derived from
+        CollectionNodeModule.
 
     Methods:
     -------
@@ -49,7 +52,8 @@ class EventTriggerModule(CollectionNodeModule):
 
     def __init__(self, *args, **kwargs):
         """
-        Method is used to initialize the EventTriggerModule and it's base module.
+        Method is used to initialize the EventTriggerModule and it's base
+        module.
 
         Args:
             *args:
@@ -58,6 +62,7 @@ class EventTriggerModule(CollectionNodeModule):
         super(EventTriggerModule, self).__init__(*args, **kwargs)
         self.min_ver = 90300
         self.max_ver = None
+        self.min_gpdbver = 1000000000
 
     def get_nodes(self, gid, sid, did):
         """
@@ -81,6 +86,14 @@ class EventTriggerModule(CollectionNodeModule):
         """
         return database.DatabaseModule.NODE_TYPE
 
+    @property
+    def module_use_template_javascript(self):
+        """
+        Returns whether Jinja2 template is used for generating the javascript
+        module.
+        """
+        return False
+
 
 blueprint = EventTriggerModule(__name__)
 
@@ -99,9 +112,6 @@ class EventTriggerView(PGChildNodeView):
     * __init__(**kwargs)
       - Method is used to initialize the EventTriggerView and it's base view.
 
-    * module_js()
-      - Returns the javascript module for event trigger.
-
     * check_precondition()
       - This function will behave as a decorator which will checks
         database connection before running view, it will also attaches
@@ -154,7 +164,7 @@ class EventTriggerView(PGChildNodeView):
     operations = dict({
         'obj': [
             {'get': 'properties', 'delete': 'delete', 'put': 'update'},
-            {'get': 'list', 'post': 'create'}
+            {'get': 'list', 'post': 'create', 'delete': 'delete'}
         ],
         'nodes': [{'get': 'node'}, {'get': 'nodes'}],
         'children': [{'get': 'children'}],
@@ -163,22 +173,9 @@ class EventTriggerView(PGChildNodeView):
         'stats': [{'get': 'statistics'}],
         'dependency': [{'get': 'dependencies'}],
         'dependent': [{'get': 'dependents'}],
-        'module.js': [{}, {}, {'get': 'module_js'}],
         'fopts': [{'get': 'get_event_funcs'}, {'get': 'get_event_funcs'}]
     })
 
-    def module_js(self):
-        """
-        Returns the javascript module for event trigger.
-        """
-        return make_response(
-            render_template(
-                "event_triggers/js/event_trigger.js",
-                _=gettext
-            ),
-            200, {'Content-Type': 'application/x-javascript'}
-        )
-
     def check_precondition(f):
         """
         This function will behave as a decorator which will checks
@@ -189,9 +186,12 @@ class EventTriggerView(PGChildNodeView):
         @wraps(f)
         def wrap(*args, **kwargs):
 
-            # Here - args[0] will always hold self & kwargs will hold gid, sid, did
+            # Here - args[0] will always hold self & kwargs will hold gid,
+            # sid, did
             self = args[0]
-            self.manager = get_driver(PG_DEFAULT_DRIVER).connection_manager(kwargs['sid'])
+            self.manager = get_driver(
+                PG_DEFAULT_DRIVER
+            ).connection_manager(kwargs['sid'])
             self.conn = self.manager.connection(did=kwargs['did'])
             self.template_path = 'event_triggers/sql/9.3_plus'
 
@@ -227,8 +227,8 @@ class EventTriggerView(PGChildNodeView):
     @check_precondition
     def nodes(self, gid, sid, did):
         """
-        This function is used to create all the child nodes within the collection.
-        Here it will create all the event trigger nodes.
+        This function is used to create all the child nodes within the
+        collection. Here it will create all the event trigger nodes.
 
         Args:
           gid: Server Group ID
@@ -323,7 +323,10 @@ class EventTriggerView(PGChildNodeView):
         Returns:
 
         """
-        sql = render_template("/".join([self.template_path, 'properties.sql']), etid=etid, conn=self.conn)
+        sql = render_template(
+            "/".join([self.template_path, 'properties.sql']),
+            etid=etid, conn=self.conn
+        )
         status, res = self.conn.execute_dict(sql)
         if not status:
             return internal_server_error(errormsg=res)
@@ -379,18 +382,27 @@ class EventTriggerView(PGChildNodeView):
                 )
             )
         try:
-            sql = render_template("/".join([self.template_path, 'create.sql']), data=data, conn=self.conn)
+            sql = render_template(
+                "/".join([self.template_path, 'create.sql']),
+                data=data, conn=self.conn
+            )
             status, res = self.conn.execute_scalar(sql)
             if not status:
                 return internal_server_error(errormsg=res)
-            sql = render_template("/".join([self.template_path, 'grant.sql']), data=data, conn=self.conn)
+            sql = render_template(
+                "/".join([self.template_path, 'grant.sql']),
+                data=data, conn=self.conn
+            )
             sql = sql.strip('\n').strip(' ')
 
             status, res = self.conn.execute_scalar(sql)
             if not status:
                 return internal_server_error(errormsg=res)
 
-            sql = render_template("/".join([self.template_path, 'get_oid.sql']), data=data)
+            sql = render_template(
+                "/".join([self.template_path, 'get_oid.sql']),
+                data=data
+            )
             status, etid = self.conn.execute_scalar(sql)
             if not status:
                 return internal_server_error(errormsg=etid)
@@ -427,13 +439,19 @@ class EventTriggerView(PGChildNodeView):
 
         try:
             sql = self.get_sql(data, etid)
+            # Most probably this is due to error
+            if not isinstance(sql, (str, unicode)):
+                return sql
             sql = sql.strip('\n').strip(' ')
             if sql != "":
                 status, res = self.conn.execute_scalar(sql)
                 if not status:
                     return internal_server_error(errormsg=res)
 
-                sql = render_template("/".join([self.template_path, 'get_oid.sql']), data=data)
+                sql = render_template(
+                    "/".join([self.template_path, 'get_oid.sql']),
+                    data=data
+                )
                 status, etid = self.conn.execute_scalar(sql)
 
                 return jsonify(
@@ -460,7 +478,7 @@ class EventTriggerView(PGChildNodeView):
             return internal_server_error(errormsg=str(e))
 
     @check_precondition
-    def delete(self, gid, sid, did, etid):
+    def delete(self, gid, sid, did, etid=None):
         """
         This function will delete an existing event trigger object.
 
@@ -479,42 +497,51 @@ class EventTriggerView(PGChildNodeView):
             cascade = True
         else:
             cascade = False
+
+        if etid is None:
+            data = request.form if request.form else json.loads(
+                request.data, encoding='utf-8'
+            )
+        else:
+            data = {'ids': [etid]}
+
         try:
-            sql = render_template("/".join([self.template_path, 'delete.sql']), etid=etid)
-            status, name = self.conn.execute_scalar(sql)
-            if not status:
-                return internal_server_error(errormsg=name)
-
-            if name is None:
-                return make_json_response(
-                    status=410,
-                    success=0,
-                    errormsg=gettext(
-                        'Error: Object not found.'
-                    ),
-                    info=gettext(
-                        'The specified event trigger could not be found.\n'
-                    )
+            for etid in data['ids']:
+                sql = render_template(
+                    "/".join([self.template_path, 'delete.sql']),
+                    etid=etid
                 )
+                status, name = self.conn.execute_scalar(sql)
+                if not status:
+                    return internal_server_error(errormsg=name)
 
-            sql = render_template("/".join([self.template_path, 'delete.sql']), name=name, cascade=cascade)
-            status, res = self.conn.execute_scalar(sql)
-            if not status:
-                return internal_server_error(errormsg=res)
+                if name is None:
+                    return make_json_response(
+                        status=410,
+                        success=0,
+                        errormsg=gettext(
+                            'Error: Object not found.'
+                        ),
+                        info=gettext(
+                            'The specified event trigger could not be found.\n'
+                        )
+                    )
+
+                sql = render_template(
+                    "/".join([self.template_path, 'delete.sql']),
+                    name=name, cascade=cascade
+                )
+                status, res = self.conn.execute_scalar(sql)
+                if not status:
+                    return internal_server_error(errormsg=res)
 
             return make_json_response(
                 success=1,
-                info=gettext("Event trigger dropped"),
-                data={
-                    'id': etid,
-                    'sid': sid,
-                    'gid': gid,
-                    'did': did
-                }
+                info=gettext("Event trigger dropped")
             )
 
         except Exception as e:
-            return internal_server_error(errormsg=str(e))
+                return internal_server_error(errormsg=str(e))
 
     @check_precondition
     def msql(self, gid, sid, did, etid=None):
@@ -539,7 +566,11 @@ class EventTriggerView(PGChildNodeView):
                 data[k] = v
         try:
             sql = self.get_sql(data, etid)
+            # Most probably this is due to error
+            if not isinstance(sql, (str, unicode)):
+                return sql
             sql = sql.strip('\n').strip(' ')
+            sql = re.sub('\n{2,}', '\n\n', sql)
             if sql == '':
                 sql = "--modified SQL"
             return make_json_response(
@@ -566,7 +597,10 @@ class EventTriggerView(PGChildNodeView):
         ]
 
         if etid is not None:
-            sql = render_template("/".join([self.template_path, 'properties.sql']), etid=etid)
+            sql = render_template(
+                "/".join([self.template_path, 'properties.sql']),
+                etid=etid
+            )
             status, res = self.conn.execute_dict(sql)
             if not status:
                 return internal_server_error(errormsg=res)
@@ -582,7 +616,10 @@ class EventTriggerView(PGChildNodeView):
             for arg in required_args:
                 if arg not in data:
                     data[arg] = old_data[arg]
-            sql = render_template("/".join([self.template_path, 'update.sql']), data=data, o_data=old_data)
+            sql = render_template(
+                "/".join([self.template_path, 'update.sql']),
+                data=data, o_data=old_data
+            )
         else:
             required_args = {
                 'name': 'Name',
@@ -603,16 +640,22 @@ class EventTriggerView(PGChildNodeView):
                         "Could not find the required parameter %s." % err
                     )
                 )
-            sql = render_template("/".join([self.template_path, 'create.sql']), data=data)
+            sql = render_template(
+                "/".join([self.template_path, 'create.sql']),
+                data=data
+            )
             sql += "\n"
-            sql += render_template("/".join([self.template_path, 'grant.sql']), data=data)
+            sql += render_template(
+                "/".join([self.template_path, 'grant.sql']),
+                data=data
+            )
         return sql
 
     @check_precondition
     def sql(self, gid, sid, did, etid):
         """
-        This function will generate sql to show in the sql pane for the selected
-        event trigger node.
+        This function will generate sql to show in the sql pane for the
+        selected event trigger node.
 
         Args:
           gid: Server Group ID
@@ -623,24 +666,43 @@ class EventTriggerView(PGChildNodeView):
         Returns:
 
         """
-        sql = render_template("/".join([self.template_path, 'properties.sql']), etid=etid)
+        sql = render_template(
+            "/".join([self.template_path, 'properties.sql']),
+            etid=etid
+        )
         status, res = self.conn.execute_dict(sql)
         if not status:
             return internal_server_error(errormsg=res)
 
+        if len(res['rows']) == 0:
+            return gone(
+                _("Could not find the specified event trigger on the server.")
+            )
+
         result = res['rows'][0]
         result = self._formatter(result)
 
-        sql = render_template("/".join([self.template_path, 'create.sql']), data=result, conn=self.conn)
+        sql = render_template(
+            "/".join([self.template_path, 'create.sql']),
+            data=result, conn=self.conn
+        )
         sql += "\n\n"
-        sql += render_template("/".join([self.template_path, 'grant.sql']), data=result, conn=self.conn)
+        sql += render_template(
+            "/".join([self.template_path, 'grant.sql']),
+            data=result, conn=self.conn
+        )
 
-        db_sql = render_template("/".join([self.template_path, 'get_db.sql']), did=did)
+        db_sql = render_template(
+            "/".join([self.template_path, 'get_db.sql']),
+            did=did
+        )
         status, db_name = self.conn.execute_scalar(db_sql)
         if not status:
             return internal_server_error(errormsg=db_name)
 
-        sql_header = u"-- Event Trigger: {0} on database {1}\n\n-- ".format(result['name'], db_name)
+        sql_header = u"-- Event Trigger: {0} on database {1}\n\n-- ".format(
+            result['name'], db_name
+        )
 
         sql_header += render_template(
             "/".join([self.template_path, 'delete.sql']),
@@ -648,6 +710,7 @@ class EventTriggerView(PGChildNodeView):
         sql_header += "\n"
 
         sql = sql_header + sql
+        sql = re.sub('\n{2,}', '\n\n', sql)
 
         return ajax_response(response=sql)
 
@@ -667,7 +730,9 @@ class EventTriggerView(PGChildNodeView):
 
         """
         res = [{'label': '', 'value': ''}]
-        sql = render_template("/".join([self.template_path, 'eventfunctions.sql']))
+        sql = render_template(
+            "/".join([self.template_path, 'eventfunctions.sql'])
+        )
         status, rest = self.conn.execute_2darray(sql)
         if not status:
             return internal_server_error(errormsg=rest)
