@@ -2,28 +2,27 @@
 #
 # pgAdmin 4 - PostgreSQL Tools
 #
-# Copyright (C) 2013 - 2017, The pgAdmin Development Team
+# Copyright (C) 2013 - 2019, The pgAdmin Development Team
 # This software is released under the PostgreSQL Licence
 #
 ##########################################################################
 
 """Implements the Domain Constraint Module."""
 
-import simplejson as json
 from functools import wraps
 
+import simplejson as json
+from flask import render_template, request, jsonify
+from flask_babelex import gettext
+
 import pgadmin.browser.server_groups.servers.databases.schemas.domains \
     as domains
-from flask import render_template, make_response, request, jsonify
-from flask_babel import gettext
+from config import PG_DEFAULT_DRIVER
 from pgadmin.browser.collection import CollectionNodeModule
 from pgadmin.browser.utils import PGChildNodeView
 from pgadmin.utils.ajax import make_json_response, internal_server_error, \
-    make_response as ajax_response
+    make_response as ajax_response, gone
 from pgadmin.utils.driver import get_driver
-from pgadmin.utils.ajax import gone
-
-from config import PG_DEFAULT_DRIVER
 
 
 class DomainConstraintModule(CollectionNodeModule):
@@ -88,6 +87,14 @@ class DomainConstraintModule(CollectionNodeModule):
             )
         ]
 
+    @property
+    def module_use_template_javascript(self):
+        """
+        Returns whether Jinja2 template is used for generating the javascript
+        module.
+        """
+        return False
+
 
 blueprint = DomainConstraintModule(__name__)
 
@@ -105,9 +112,6 @@ class DomainConstraintView(PGChildNodeView):
     Methods:
     -------
 
-    * module_js():
-      - Load JS file (domain_constraints.js) for this module.
-
     * check_precondition(f):
       - Works as a decorator.
       -  Checks database connection status.
@@ -163,17 +167,15 @@ class DomainConstraintView(PGChildNodeView):
     operations = dict({
         'obj': [
             {'get': 'properties', 'delete': 'delete', 'put': 'update'},
-            {'get': 'list', 'post': 'create'}
+            {'get': 'list', 'post': 'create', 'delete': 'delete'}
         ],
-        'delete': [{'delete': 'delete'}],
         'children': [{'get': 'children'}],
         'nodes': [{'get': 'node'}, {'get': 'nodes'}],
         'sql': [{'get': 'sql'}],
         'msql': [{'get': 'msql'}, {'get': 'msql'}],
         'stats': [{'get': 'statistics'}],
         'dependency': [{'get': 'dependencies'}],
-        'dependent': [{'get': 'dependents'}],
-        'module.js': [{}, {}, {'get': 'module_js'}]
+        'dependent': [{'get': 'dependents'}]
     })
 
     def validate_request(f):
@@ -209,7 +211,8 @@ class DomainConstraintView(PGChildNodeView):
                             status=410,
                             success=0,
                             errormsg=gettext(
-                                "Could not find the required parameter (%s)." % arg
+                                "Could not find the required parameter (%s)." %
+                                arg
                             )
                         )
 
@@ -229,18 +232,6 @@ class DomainConstraintView(PGChildNodeView):
 
         return wrap
 
-    def module_js(self):
-        """
-        Load JS file (domain_constraints.js) for this module.
-        """
-        return make_response(
-            render_template(
-                "domain_constraints/js/domain_constraints.js",
-                _=gettext
-            ),
-            200, {'Content-Type': 'application/x-javascript'}
-        )
-
     def check_precondition(f):
         """
         Works as a decorator.
@@ -257,9 +248,11 @@ class DomainConstraintView(PGChildNodeView):
             self.qtIdent = driver.qtIdent
 
             # Set the template path for the SQL scripts
-            self.template_path = 'domain_constraints/sql/#{0}#'.format(self.manager.version)
+            self.template_path = 'domain_constraints/sql/#{0}#'.format(
+                self.manager.version)
 
             return f(*args, **kwargs)
+
         return wrap
 
     @check_precondition
@@ -340,7 +333,6 @@ class DomainConstraintView(PGChildNodeView):
             doid: Domain Id
             coid: Domain Constraint Id
         """
-        res = []
         SQL = render_template("/".join([self.template_path,
                                         'properties.sql']),
                               coid=coid)
@@ -366,7 +358,9 @@ class DomainConstraintView(PGChildNodeView):
                 status=200
             )
 
-        return gone(gettext("Could not find the specified domain constraint."))
+        return gone(
+            gettext("Could not find the specified domain constraint.")
+        )
 
     @check_precondition
     def properties(self, gid, sid, did, scid, doid, coid):
@@ -392,7 +386,7 @@ class DomainConstraintView(PGChildNodeView):
         if len(res['rows']) == 0:
             return gone(gettext(
                 "Could not find the specified domain constraint."
-                )
+            )
             )
 
         data = res['rows'][0]
@@ -419,9 +413,9 @@ class DomainConstraintView(PGChildNodeView):
         """
         data = self.request
         try:
-            status, SQL = self.get_sql(gid, sid, data, scid, doid)
+            status, SQL, name = self.get_sql(gid, sid, data, scid, doid)
             if not status:
-                return internal_server_error(errormsg=SQL)
+                return SQL
 
             status, res = self.conn.execute_scalar(SQL)
 
@@ -455,7 +449,7 @@ class DomainConstraintView(PGChildNodeView):
             return internal_server_error(errormsg=str(e))
 
     @check_precondition
-    def delete(self, gid, sid, did, scid, doid, coid):
+    def delete(self, gid, sid, did, scid, doid, coid=None):
         """
         Drops the Domain Constraint object.
 
@@ -467,45 +461,47 @@ class DomainConstraintView(PGChildNodeView):
             doid: Domain Id
             coid: Domain Constraint Id
         """
+        if coid is None:
+            data = request.form if request.form else json.loads(
+                request.data, encoding='utf-8'
+            )
+        else:
+            data = {'ids': [coid]}
+
         try:
-            SQL = render_template("/".join([self.template_path,
-                                            'properties.sql']),
-                                  doid=doid, coid=coid)
-            status, res = self.conn.execute_dict(SQL)
+            for coid in data['ids']:
+                SQL = render_template("/".join([self.template_path,
+                                                'properties.sql']),
+                                      doid=doid, coid=coid)
+                status, res = self.conn.execute_dict(SQL)
 
-            if not status:
-                return internal_server_error(errormsg=res)
+                if not status:
+                    return internal_server_error(errormsg=res)
 
-            if not res['rows']:
-                return make_json_response(
-                    success=0,
-                    errormsg=gettext(
-                        'Error: Object not found.'
-                    ),
-                    info=gettext(
-                        'The specified domain constraint could not be found.\n'
+                if not res['rows']:
+                    return make_json_response(
+                        success=0,
+                        errormsg=gettext(
+                            'Error: Object not found.'
+                        ),
+                        info=gettext(
+                            'The specified domain constraint '
+                            'could not be found.\n'
+                        )
                     )
-                )
 
-            data = res['rows'][0]
+                data = res['rows'][0]
 
-            SQL = render_template("/".join([self.template_path,
-                                            'delete.sql']),
-                                  data=data)
-            status, res = self.conn.execute_scalar(SQL)
-            if not status:
-                return internal_server_error(errormsg=res)
+                SQL = render_template("/".join([self.template_path,
+                                                'delete.sql']),
+                                      data=data)
+                status, res = self.conn.execute_scalar(SQL)
+                if not status:
+                    return internal_server_error(errormsg=res)
 
             return make_json_response(
                 success=1,
-                info=gettext("Domain Constraint dropped"),
-                data={
-                    'id': doid,
-                    'scid': scid,
-                    'sid': sid,
-                    'gid': gid,
-                    'did': did
-                }
+                info=gettext("Domain Constraint dropped")
             )
 
         except Exception as e:
@@ -526,7 +522,9 @@ class DomainConstraintView(PGChildNodeView):
             coid: Domain Constraint Id
         """
         data = self.request
-        status, SQL = self.get_sql(gid, sid, data, scid, doid, coid)
+        status, SQL, name = self.get_sql(gid, sid, data, scid, doid, coid)
+        if not status:
+            return SQL
 
         try:
             if SQL and status:
@@ -541,18 +539,13 @@ class DomainConstraintView(PGChildNodeView):
                 else:
                     icon = ''
 
-                return make_json_response(
-                    success=1,
-                    info="Domain Constraint updated",
-                    data={
-                        'id': coid,
-                        'doid': doid,
-                        'scid': scid,
-                        'sid': sid,
-                        'gid': gid,
-                        'did': did,
-                        'icon': icon
-                    }
+                return jsonify(
+                    node=self.blueprint.generate_browser_node(
+                        coid,
+                        doid,
+                        name,
+                        icon=icon
+                    )
                 )
             else:
                 return make_json_response(
@@ -594,6 +587,11 @@ class DomainConstraintView(PGChildNodeView):
         status, res = self.conn.execute_dict(SQL)
         if not status:
             return internal_server_error(errormsg=res)
+        if len(res['rows']) == 0:
+            return gone(gettext(
+                "Could not find the specified domain constraint."
+            )
+            )
 
         data = res['rows'][0]
 
@@ -631,7 +629,7 @@ class DomainConstraintView(PGChildNodeView):
         """
         data = self.request
 
-        status, SQL = self.get_sql(gid, sid, data, scid, doid, coid)
+        status, SQL, name = self.get_sql(gid, sid, data, scid, doid, coid)
         if status and SQL:
             return make_json_response(
                 data=SQL,
@@ -661,6 +659,11 @@ class DomainConstraintView(PGChildNodeView):
 
                 if not status:
                     return False, internal_server_error(errormsg=res)
+                if len(res['rows']) == 0:
+                    return False, gone(gettext(
+                        "Could not find the specified domain constraint."
+                    )
+                    )
 
                 old_data = res['rows'][0]
 
@@ -674,9 +677,12 @@ class DomainConstraintView(PGChildNodeView):
                 SQL = render_template("/".join([self.template_path,
                                                 'create.sql']),
                                       data=data, domain=domain, schema=schema)
-            return True, SQL.strip('\n')
+            if 'name' in data:
+                return True, SQL.strip('\n'), data['name']
+            else:
+                return True, SQL.strip('\n'), old_data['name']
         except Exception as e:
-            return False, internal_server_error(errormsg=str(e))
+            return False, internal_server_error(errormsg=str(e)), None
 
     def _get_domain(self, doid):
         """
