@@ -29,7 +29,7 @@ define('pgadmin.node.index', [
         dialogHelp: url_for('help.static', {'filename': 'index_dialog.html'}),
         columns: ['name', 'description'],
         hasStatistics: true,
-        statsPrettifyFields: ['Size', 'Index size'],
+        statsPrettifyFields: [gettext('Size'), gettext('Index size')],
         canDrop: SchemaChildTreeNode.isTreeItemOfChildOfSchema,
         canDropCascade: SchemaChildTreeNode.isTreeItemOfChildOfSchema,
       });
@@ -147,8 +147,6 @@ define('pgadmin.node.index', [
         deps: ['amname'],
         options: {
           'onText': 'DESC', 'offText': 'ASC',
-          'onColor': 'success', 'offColor': 'primary',
-          'size': 'small',
         },
       },{
         id: 'nulls', label: gettext('NULLs'),
@@ -170,8 +168,6 @@ define('pgadmin.node.index', [
         deps: ['amname', 'sort_order'],
         options: {
           'onText': 'FIRST', 'offText': 'LAST',
-          'onColor': 'success', 'offColor': 'primary',
-          'size': 'small',
         },
       },
     ],
@@ -236,7 +232,7 @@ define('pgadmin.node.index', [
       hasSQL:  true,
       hasDepends: true,
       hasStatistics: true,
-      statsPrettifyFields: ['Size', 'Index size'],
+      statsPrettifyFields: [gettext('Size'), gettext('Index size')],
       Init: function() {
         /* Avoid mulitple registration of menus */
         if (this.initialized)
