@@ -30,9 +30,9 @@ define('pgadmin.node.table', [
         type: 'coll-table',
         columns: ['name', 'relowner', 'is_partitioned', 'description'],
         hasStatistics: true,
-        statsPrettifyFields: ['Size', 'Indexes size', 'Table size',
-          'Toast table size', 'Tuple length',
-          'Dead tuple length', 'Free space'],
+        statsPrettifyFields: [gettext('Size'), gettext('Indexes size'), gettext('Table size'),
+          gettext('Toast table size'), gettext('Tuple length'),
+          gettext('Dead tuple length'), gettext('Free space')],
         canDrop: SchemaChildTreeNode.isTreeItemOfChildOfSchema,
         canDropCascade: SchemaChildTreeNode.isTreeItemOfChildOfSchema,
       });
@@ -46,9 +46,9 @@ define('pgadmin.node.table', [
       hasSQL: true,
       hasDepends: true,
       hasStatistics: true,
-      statsPrettifyFields: ['Size', 'Indexes size', 'Table size',
-        'Toast table size', 'Tuple length',
-        'Dead tuple length', 'Free space'],
+      statsPrettifyFields: [gettext('Size'), gettext('Indexes size'), gettext('Table size'),
+        gettext('Toast table size'), gettext('Tuple length'),
+        gettext('Dead tuple length'), gettext('Free space')],
       sqlAlterHelp: 'sql-altertable.html',
       sqlCreateHelp: 'sql-createtable.html',
       dialogHelp: url_for('help.static', {'filename': 'table_dialog.html'}),
