@@ -2,7 +2,7 @@
 #
 # pgAdmin 4 - PostgreSQL Tools
 #
-# Copyright (C) 2013 - 2017, The pgAdmin Development Team
+# Copyright (C) 2013 - 2019, The pgAdmin Development Team
 # This software is released under the PostgreSQL Licence
 #
 ##########################################################################
@@ -12,9 +12,10 @@
 import json
 
 from flask import render_template
+
 from pgadmin.browser.collection import CollectionNodeModule
 from pgadmin.utils.ajax import internal_server_error
-from config import PG_DEFAULT_DRIVER
+
 
 class SchemaChildModule(CollectionNodeModule):
     """
@@ -43,25 +44,40 @@ class SchemaChildModule(CollectionNodeModule):
 
     def BackendSupported(self, manager, **kwargs):
         return (
-                   (
-                       kwargs['is_catalog'] and ((
-                                                     self.CATALOG_DB_SUPPORTED and kwargs['db_support']
-                                                 ) or (
-                                                     not self.CATALOG_DB_SUPPORTED and
-                                                     not kwargs['db_support'] and
-                                                     (
-                                                         self.SUPPORTED_SCHEMAS is None or (
-                                                             kwargs['schema_name'] in self.SUPPORTED_SCHEMAS
-                                                         )
-                                                     )
-                                                 ))
-                   ) or (
-                       not kwargs['is_catalog'] and self.CATALOG_DB_SUPPORTED
-                   )
-               ) and CollectionNodeModule.BackendSupported(
-            self, manager, **kwargs
+            (
+                (
+                    kwargs['is_catalog'] and
+                    (
+                        (
+                            self.CATALOG_DB_SUPPORTED and
+                            kwargs['db_support']
+                        ) or (
+                            not self.CATALOG_DB_SUPPORTED and
+                            not kwargs[
+                                'db_support'] and
+                            (
+                                self.SUPPORTED_SCHEMAS is None or
+                                kwargs[
+                                    'schema_name'] in self.SUPPORTED_SCHEMAS
+                            )
+                        )
+                    )
+                ) or
+                (
+                    not kwargs['is_catalog'] and self.CATALOG_DB_SUPPORTED
+                )
+            ) and
+            CollectionNodeModule.BackendSupported(self, manager, **kwargs)
         )
 
+    @property
+    def module_use_template_javascript(self):
+        """
+        Returns whether Jinja2 template is used for generating the javascript
+        module.
+        """
+        return False
+
 
 class DataTypeReader:
     """
@@ -75,7 +91,7 @@ class DataTypeReader:
       - Returns data-types on the basis of the condition provided.
     """
 
-    def get_types(self, conn, condition, add_serials=False):
+    def get_types(self, conn, condition, add_serials=False, schema_oid=''):
         """
         Returns data-types including calculation for Length and Precision.
 
@@ -83,14 +99,26 @@ class DataTypeReader:
             conn: Connection Object
             condition: condition to restrict SQL statement
             add_serials: If you want to serials type
+            schema_oid: If needed pass the schema OID to restrict the search
         """
         res = []
         try:
-
+            # Check if template path is already set or not
+            # if not then we will set the template path here
+            if not hasattr(self, 'data_type_template_path'):
+                self.data_type_template_path = 'datatype/sql/' + (
+                    '#{0}#{1}#'.format(
+                        self.manager.server_type,
+                        self.manager.version
+                    ) if self.manager.server_type == 'gpdb' else
+                    '#{0}#'.format(self.manager.version)
+                )
             SQL = render_template(
-                '/datatype/sql/#{0}#/get_types.sql'.format(conn.manager.version),
+                "/".join([self.data_type_template_path, 'get_types.sql']),
                 condition=condition,
-                add_serials=add_serials)
+                add_serials=add_serials,
+                schema_oid=schema_oid
+            )
             status, rset = conn.execute_2darray(SQL)
             if not status:
                 return status, rset
@@ -103,25 +131,12 @@ class DataTypeReader:
                 min_val = 0
                 max_val = 0
 
-                # Check against PGOID for specific type
+                # Check if the type will have length and precision or not
                 if row['elemoid']:
-                    if row['elemoid'] in (1560, 1561, 1562, 1563, 1042, 1043,
-                                          1014, 1015):
-                        typeval = 'L'
-                    elif row['elemoid'] in (1083, 1114, 1115, 1183, 1184, 1185,
-                                            1186, 1187, 1266, 1270):
-                        typeval = 'D'
-                    elif row['elemoid'] in (1231, 1700):
-                        typeval = 'P'
-                    else:
-                        typeval = ' '
+                    length, precision, typeval = self.get_length_precision(
+                        row['elemoid'])
 
-                # Set precision & length/min/max values
-                if typeval == 'P':
-                    precision = True
-
-                if precision or typeval in ('L', 'D'):
-                    length = True
+                if length:
                     min_val = 0 if typeval == 'D' else 1
                     if precision:
                         max_val = 1000
@@ -143,6 +158,54 @@ class DataTypeReader:
 
         return True, res
 
+    @staticmethod
+    def get_length_precision(elemoid_or_name):
+        precision = False
+        length = False
+        typeval = ''
+
+        # Check against PGOID/typename for specific type
+        if elemoid_or_name:
+            if elemoid_or_name in (1560, 'bit',
+                                   1561, 'bit[]',
+                                   1562, 'varbit', 'bit varying',
+                                   1563, 'varbit[]', 'bit varying[]',
+                                   1042, 'bpchar', 'character',
+                                   1043, 'varchar', 'character varying',
+                                   1014, 'bpchar[]', 'character[]',
+                                   1015, 'varchar[]', 'character varying[]'):
+                typeval = 'L'
+            elif elemoid_or_name in (1083, 'time', 'time without time zone',
+                                     1114, 'timestamp',
+                                     'timestamp without time zone',
+                                     1115, 'timestamp[]',
+                                     'timestamp without time zone[]',
+                                     1183, 'time[]',
+                                     'time without time zone[]',
+                                     1184, 'timestamptz',
+                                     'timestamp with time zone',
+                                     1185, 'timestamptz[]',
+                                     'timestamp with time zone[]',
+                                     1186, 'interval',
+                                     1187, 'interval[]', 'interval[]',
+                                     1266, 'timetz', 'time with time zone',
+                                     1270, 'timetz', 'time with time zone[]'):
+                typeval = 'D'
+            elif elemoid_or_name in (1231, 'numeric[]',
+                                     1700, 'numeric'):
+                typeval = 'P'
+            else:
+                typeval = ' '
+
+        # Set precision & length/min/max values
+        if typeval == 'P':
+            precision = True
+
+        if precision or typeval in ('L', 'D'):
+            length = True
+
+        return length, precision, typeval
+
     def get_full_type(self, nsp, typname, isDup, numdims, typmod):
         """
         Returns full type name with Length and Precision.
@@ -151,14 +214,13 @@ class DataTypeReader:
             conn: Connection Object
             condition: condition to restrict SQL statement
         """
-        needSchema = isDup
         schema = nsp if nsp is not None else ''
         name = ''
         array = ''
         length = ''
 
-        # Above 7.4, format_type also sends the schema name if it's not included
-        # in the search_path, so we need to skip it in the typname
+        # Above 7.4, format_type also sends the schema name if it's not
+        # included in the search_path, so we need to skip it in the typname
         if typname.find(schema + '".') >= 0:
             name = typname[len(schema) + 3]
         elif typname.find(schema + '.') >= 0:
@@ -187,22 +249,24 @@ class DataTypeReader:
         if typmod != -1:
             length = '('
             if name == 'numeric':
-                _len = (typmod - 4) >> 16;
-                _prec = (typmod - 4) & 0xffff;
+                _len = (typmod - 4) >> 16
+                _prec = (typmod - 4) & 0xffff
                 length += str(_len)
-                if (_prec):
+                if _prec is not None:
                     length += ',' + str(_prec)
-            elif name == 'time' or \
-                            name == 'timetz' or \
-                            name == 'time without time zone' or \
-                            name == 'time with time zone' or \
-                            name == 'timestamp' or \
-                            name == 'timestamptz' or \
-                            name == 'timestamp without time zone' or \
-                            name == 'timestamp with time zone' or \
-                            name == 'bit' or \
-                            name == 'bit varying' or \
-                            name == 'varbit':
+            elif (
+                name == 'time' or
+                name == 'timetz' or
+                name == 'time without time zone' or
+                name == 'time with time zone' or
+                name == 'timestamp' or
+                name == 'timestamptz' or
+                name == 'timestamp without time zone' or
+                name == 'timestamp with time zone' or
+                name == 'bit' or
+                name == 'bit varying' or
+                name == 'varbit'
+            ):
                 _prec = 0
                 _len = typmod
                 length += str(_len)
@@ -519,7 +583,8 @@ class VacuumSettings:
         elif type is 'toast':
             for row in res['rows']:
                 row_old_name = row['name']
-                row_name = 'toast_{0}'.format(vacuum_fields[type][row_old_name][0])
+                row_name = 'toast_{0}'.format(
+                    vacuum_fields[type][row_old_name][0])
                 row['name'] = vacuum_fields[type][row_old_name][0]
                 row['label'] = vacuum_fields[type][row_old_name][1]
                 row['column_type'] = vacuum_fields[type][row_old_name][2]
