@@ -24,7 +24,7 @@ define('pgadmin.node.database', [
         hasStatistics: true,
         canDrop: true,
         canDropCascade: false,
-        statsPrettifyFields: ['Size', 'Size of temporary files'],
+        statsPrettifyFields: [gettext('Size'), gettext('Size of temporary files')],
       });
   }
 
@@ -38,7 +38,7 @@ define('pgadmin.node.database', [
       hasSQL: true,
       hasDepends: true,
       hasStatistics: true,
-      statsPrettifyFields: ['Size', 'Size of temporary files'],
+      statsPrettifyFields: [gettext('Size'), gettext('Size of temporary files')],
       canDrop: function(node) {
         return node.canDrop;
       },
@@ -385,18 +385,10 @@ define('pgadmin.node.database', [
           id: 'is_template', label: gettext('Template?'),
           editable: false, type: 'switch', group: gettext('Definition'),
           disabled: true,  mode: ['properties', 'edit'],
-          options: {
-            'onText': gettext('Yes'), 'offText': gettext('No'),
-            'onColor': 'success', 'offColor': 'primary',
-          },
         },{
           id: 'datallowconn', label: gettext('Allow connections?'),
           editable: false, type: 'switch', group: gettext('Definition'),
           mode: ['properties'], disabled: true,
-          options: {
-            'onText': gettext('Yes'), 'offText': gettext('No'),
-            'onColor': 'success', 'offColor': 'primary',
-          },
         },{
           id: 'datacl', label: gettext('Privileges'), type: 'collection',
           model: pgBrowser.Node.PrivilegeRoleModel.extend({
