@@ -999,8 +999,17 @@ define('pgadmin.browser.node', [
           });
       },
       opened: function(item) {
+        let tree = pgBrowser.tree,
+          auto_expand = pgBrowser.get_preference('browser', 'auto_expand_sole_children');
+
         pgBrowser.Events.trigger('pgadmin:browser:tree:update-tree-state',
          item);
+
+        if (auto_expand && auto_expand.value == true && tree.children(item).length == 1) {
+          // Automatically expand the child node, if a treeview node has only a single child.
+          tree.open(tree.first(item));
+        }
+
       },
       closed: function(item) {
         pgBrowser.Events.trigger('pgadmin:browser:tree:remove-from-tree-state',
@@ -1201,15 +1210,6 @@ define('pgadmin.browser.node', [
           j.append(content);
         }.bind(panel),
         onSqlHelp = function() {
-          // See if we can find an existing panel, if not, create one
-          var pnlSqlHelp = pgBrowser.docker.findPanels('pnl_sql_help')[0];
-
-          if (pnlSqlHelp == null) {
-            var pnlProperties = pgBrowser.docker.findPanels('properties')[0];
-            pgBrowser.docker.addPanel('pnl_sql_help', wcDocker.DOCK.STACKED, pnlProperties);
-            pnlSqlHelp = pgBrowser.docker.findPanels('pnl_sql_help')[0];
-          }
-
           // Construct the URL
           var server = that.getTreeNodeHierarchy(item).server;
 
@@ -1237,29 +1237,11 @@ define('pgadmin.browser.node', [
             }
           }
 
-          // Update the panel
-          var iframe = $(pnlSqlHelp).data('embeddedFrame');
-          pnlSqlHelp.title('SQL: ' + that.label);
-
-          pnlSqlHelp.focus();
-          iframe.openURL(url);
+          window.open(url, 'postgres_help');
         }.bind(panel),
 
         onDialogHelp = function() {
-          // See if we can find an existing panel, if not, create one
-          var pnlDialogHelp = pgBrowser.docker.findPanels('pnl_online_help')[0];
-
-          if (pnlDialogHelp == null) {
-            var pnlProperties = pgBrowser.docker.findPanels('properties')[0];
-            pgBrowser.docker.addPanel('pnl_online_help', wcDocker.DOCK.STACKED, pnlProperties);
-            pnlDialogHelp = pgBrowser.docker.findPanels('pnl_online_help')[0];
-          }
-
-          // Update the panel
-          var iframe = $(pnlDialogHelp).data('embeddedFrame');
-
-          pnlDialogHelp.focus();
-          iframe.openURL(that.dialogHelp);
+          window.open(that.dialogHelp, 'pgadmin_help');
         }.bind(panel),
 
         onSave = function(view, saveBtn) {
