@@ -13,7 +13,9 @@
  * @namespace Slick
  */
 
-(function($) {
+import JSONBigNumber from 'json-bignumber';
+
+(function($, JSONBigNumber) {
   // register namespace
   $.extend(true, window, {
     'Slick': {
@@ -33,12 +35,12 @@
 
   // return wrapper element
   function getWrapper() {
-    return $('<div class=\'pg_text_editor\' />');
+    return $('<div class=\'pg-text-editor\' />');
   }
 
   // return textarea element
   function getTextArea() {
-    return $('<textarea class=\'pg_textarea text-12\' hidefocus rows=5\'>');
+    return $('<textarea class=\'pg-textarea text-12\' hidefocus rows=5\'>');
   }
 
   // Generate and return editor buttons
@@ -107,25 +109,18 @@
         grid.copied_rows[row][cell] = 1;
       }
     } else {
-      item[args.column.field] = state;
+      if(column_type === 'jsonb') {
+        item[args.column.field] = JSONBigNumber.stringify(JSONBigNumber.parse(state));
+      } else {
+        item[args.column.field] = state;
+      }
     }
   }
 
   function calculateEditorPosition(position, $wrapper) {
     var $edit_grid = $wrapper.parent().find('#datagrid');
-    var _elem_height = $edit_grid.height(),
-      is_hidden, _position;
-    // We cannot display editor partially visible so we will lift it above select column
-    if (position.top > _elem_height) {
-      is_hidden = position.bottom - _elem_height;
-    }
 
-    if (is_hidden) {
-      _position = position.top - is_hidden;
-    } else {
-      _position = position.top - 7;
-    }
-    position.top = _position;
+    position.top = position.top - $wrapper.height();
 
     var grid_width = $edit_grid.width(),
       popup_width = $wrapper.width() + 32;
@@ -364,19 +359,21 @@
 
     this.loadValue = function(item) {
       var data = defaultValue = item[args.column.field];
-      if (data && typeof data === 'object' && !Array.isArray(data)) {
-        data = JSON.stringify(data, null, 4);
+      /* If jsonb or array */
+      if(args.column.column_type_internal === 'jsonb' && !Array.isArray(data)) {
+        data = JSONBigNumber.stringify(JSONBigNumber.parse(data), null, 4);
       } else if (Array.isArray(data)) {
         var temp = [];
         $.each(data, function(i, val) {
           if (typeof val === 'object') {
-            temp.push(JSON.stringify(val, null, 4));
+            temp.push(JSONBigNumber.stringify(val, null, 4));
           } else {
             temp.push(val);
           }
         });
         data = '[' + temp.join() + ']';
       }
+      /* if json take as is */
       $input.val(data);
       $input.trigger('select');
     };
@@ -388,8 +385,12 @@
       return $input.val();
     };
 
-    this.applyValue = function(item, state) {
-      setValue(args, item, state, 'text');
+    this.applyValue = function(item, state){
+      if(args.column.column_type_internal === 'jsonb') {
+        setValue(args, item, state, 'jsonb');
+      } else {
+        setValue(args, item, state, 'text');
+      }
     };
 
     this.isValueChanged = function() {
@@ -401,13 +402,18 @@
     };
 
     this.validate = function() {
-      if (args.column.validator) {
-        var validationResults = args.column.validator($input.val());
-        if (!validationResults.valid) {
-          return validationResults;
+      if(args.column.column_type_internal === 'jsonb' ||
+          args.column.column_type_internal === 'json') {
+        try {
+          JSON.parse($input.val());
+        } catch(e) {
+          $input.addClass('pg-text-invalid');
+          return {
+            valid: false,
+          };
         }
       }
-
+      $input.removeClass('pg-text-invalid');
       return {
         valid: true,
         msg: null,
@@ -583,13 +589,13 @@
 
     this.loadValue = function(item) {
       var data = defaultValue = item[args.column.field];
-      if (typeof data === 'object' && !Array.isArray(data)) {
-        data = JSON.stringify(data, null, 4);
+      if(args.column.column_type_internal === 'jsonb' && !Array.isArray(data)) {
+        data = JSONBigNumber.stringify(JSONBigNumber.parse(data), null, 4);
       } else if (Array.isArray(data)) {
         var temp = [];
         $.each(data, function(i, val) {
           if (typeof val === 'object') {
-            temp.push(JSON.stringify(val, null, 4));
+            temp.push(JSONBigNumber.stringify(val, null, 4));
           } else {
             temp.push(val);
           }
@@ -974,4 +980,4 @@
     this.init();
   }
 
-})(window.jQuery);
+})(window.jQuery, JSONBigNumber);
