@@ -234,17 +234,7 @@ define('pgadmin.datagrid', [
           return;
         }
 
-        var nsp_name = '';
-
-        if (parentData.schema != undefined) {
-          nsp_name = parentData.schema.label;
-        }
-        else if (parentData.view != undefined) {
-          nsp_name = parentData.view.label;
-        }
-        else if (parentData.catalog != undefined) {
-          nsp_name = parentData.catalog.label;
-        }
+        let nsp_name = showData.retrieveNameSpaceName(parentData);
 
         var url_params = {
           'cmd_type': data.mnuid,
@@ -263,8 +253,8 @@ define('pgadmin.datagrid', [
           'did': url_params['did'],
           'obj_id': url_params['obj_id'],
         });
-        var grid_title = parentData.server.label + '-' + parentData.database.label + '-'
-                        + nsp_name + '.' + d.label;
+
+        let grid_title = showData.generateDatagridTitle(parentData, nsp_name, d);
 
         // Create filter dialog using alertify
         if (!alertify.filterDialog) {
@@ -457,27 +447,41 @@ define('pgadmin.datagrid', [
         var self = this,
           panel_title = trans_obj.panel_title,
           grid_title = self.get_panel_title(),
-          // Open the panel if frame is initialized
-          url_params = {
-            'trans_id': trans_obj.gridTransId,
-            'is_query_tool': trans_obj.is_query_tool,
-            'editor_title': encodeURIComponent(grid_title),
-          },
-          baseUrl = url_for('datagrid.panel', url_params) +
-            '?' + 'query_url=' + encodeURI(trans_obj.sURL) + '&server_type=' + encodeURIComponent(trans_obj.server_type);
+          panel_icon = '',
+          panel_tooltip = '';
 
-        if(trans_obj.is_query_tool == 'false') {
-          panel_title = gettext('Edit Data - ') + grid_title;
+        if (trans_obj.is_query_tool == 'false') {
+          // Edit grid titles
+          grid_title = panel_title + '/' + grid_title;
+          panel_tooltip = gettext('View/Edit Data - ') + grid_title;
+          panel_title = grid_title;
+          panel_icon = 'fa fa-table';
         } else {
-          // Create title for CREATE/DELETE scripts
           if (panel_title) {
-            panel_title =
-              sqlEditorUtils.capitalizeFirstLetter(panel_title) + ' script';
+            // Script titles
+            panel_tooltip = panel_title.toUpperCase() + ' ' + gettext('Script - ') + grid_title;
+            panel_title = grid_title;
+            panel_icon = 'fa fa-file-text-o';
           } else {
-            panel_title = gettext('Query - ') + grid_title;
+            // Query tool titles
+            panel_tooltip = gettext('Query Tool - ') + grid_title;
+            panel_title = grid_title;
+            panel_icon = 'fa fa-bolt';
           }
         }
 
+          // Open the panel if frame is initialized
+        let titileForURLObj = sqlEditorUtils.removeSlashInTheString(grid_title);
+        var url_params = {
+            'trans_id': trans_obj.gridTransId,
+            'is_query_tool': trans_obj.is_query_tool,
+            'editor_title': titileForURLObj.title,
+          },
+          baseUrl = url_for('datagrid.panel', url_params) +
+            '?' + 'query_url=' + encodeURI(trans_obj.sURL) +
+            '&server_type=' + encodeURIComponent(trans_obj.server_type) +
+            '&fslashes=' + titileForURLObj.slashLocations;
+
         if (self.preferences.new_browser_tab) {
           var newWin = window.open(baseUrl, '_blank');
 
@@ -500,8 +504,8 @@ define('pgadmin.datagrid', [
           var queryToolPanel = pgBrowser.docker.addPanel('frm_datagrid', wcDocker.DOCK.STACKED, propertiesPanel[0]);
 
           // Set panel title and icon
-          queryToolPanel.title('<span title="'+panel_title+'">'+panel_title+'</span>');
-          queryToolPanel.icon('fa fa-bolt');
+          queryToolPanel.title('<span title="'+panel_tooltip+'">'+panel_title+'</span>');
+          queryToolPanel.icon(panel_icon);
           queryToolPanel.focus();
 
           // Listen on the panel closed event.
